#' Example application to mixture likelihood
#'
#' @description
#' See the introduction vignette for details:
#' <https://loelschlaeger.de/ino/articles/ino.html>
#'
#' @docType data
#'
#' @usage data("mixture_ino")
#'
#' @format
#' A \code{\link{Nop}} object.
#'
#' @keywords
#' demo
"mixture_ino"

#' Example application to HMM likelihood
#'
#' @description
#' See the vignette about the HMM likelihood for details:
#' <https://loelschlaeger.de/ino/articles/example_hmm.html>
#'
#' @docType data
#'
#' @usage data("hmm_ino")
#'
#' @format
#' A \code{\link{Nop}} object.
#'
#' @keywords
#' demo
"hmm_ino"

#' Example application of to probit likelihood
#'
#' @description
#' See the vignette about the probit likelihood for details:
#' <https://loelschlaeger.de/ino/articles/example_probit.html>
#'
#' @docType data
#'
#' @usage data(probit_ino)
#'
#' @format
#' A \code{\link{Nop}} object.
#'
#' @keywords
#' demo
"probit_ino"
